@@ -1,20 +1,8 @@
-/**
- *  Copyright (c) 2001 David Faure <david@mandrakesoft.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001 David Faure <david@mandrakesoft.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Behaviour options for konqueror
 
@@ -32,13 +20,13 @@
 // KDE
 #include <KLocalizedString>
 
+#include <KPluginFactory>
 #include <kurlrequester.h>
 #include <kconfiggroup.h>
 #include <QStandardPaths>
 #include <KSharedConfig>
 
-// Local
-#include "konqkcmfactory.h"
+K_PLUGIN_CLASS_WITH_JSON(KBehaviourOptions, "filebehavior.json")
 
 KBehaviourOptions::KBehaviourOptions(QWidget *parent, const QVariantList &)
     : KCModule(parent)
@@ -142,3 +130,4 @@ void KBehaviourOptions::updateWinPixmap(bool b)
     }
 }
 
+#include "behaviour.moc"
