@@ -25,6 +25,7 @@ namespace KParts {
 }
 
 class QWebEngineView;
+class QWebEngineProfile;
 class WebEngineView;
 class WebEnginePage;
 class SearchBar;
@@ -66,6 +67,11 @@ public:
      */
     bool openUrl(const QUrl &) override;
 
+    /**
+     * Actually loads the URL in the page
+     */
+    void loadUrl(const QUrl & _u);
+
     /**
      * Re-implemented for internal reasons. API remains unaffected.
      *
@@ -117,6 +123,12 @@ public:
      */
     void setPage(WebEnginePage *newPage);
 
+    QWebEngineProfile *profile() const;
+
+    bool isWebEnginePart() const {return true;}
+
+    Q_PROPERTY(bool isWebEnginePart READ isWebEnginePart)
+
 public Q_SLOTS:
     void exitFullScreen();
     void setInspectedPart(KParts::ReadOnlyPart *part);
